@@ -1,6 +1,6 @@
 #' Convert antares output to h5 file
 #'
-#' @param path \code{character} folder where h5 file will be write (default getwd())
+#' @param path \code{character} folder where h5 file will be write (default NULL)
 #' @param timeSteps \code{character} timeSteps
 #' @param opts \code{list} of simulation parameters returned by the function \link{setSimulationPath}. Defaut to \code{antaresRead::simOptions()}
 #' @param writeMcAll \code{boolean} write mc-all
@@ -18,11 +18,11 @@
 #' @param writeAllSimulations \code{boolean}, write all simulations of your antares study.
 #' @param nbCores \code{numeric}, number of cores to use, only used if writeAllSimulations is TRUE
 #' @param removeVirtualAreas \code{boolean}, remove virtual areas, see \link[antaresRead]{removeVirtualAreas}
-#' @param storageFlexibility \code{character}, see \link[antaresRead]{removeVirtualAreas}
-#' @param production \code{character}, see \link[antaresRead]{removeVirtualAreas}
-#' @param reassignCosts \code{boolean}, see \link[antaresRead]{removeVirtualAreas}
-#' @param newCols \code{boolean}, see \link[antaresRead]{removeVirtualAreas}
-#' @param overwrite \code{boolean}, overwrite old file
+#' @param storageFlexibility \code{character or list}, see \link[antaresRead]{removeVirtualAreas}
+#' @param production \code{character or list}, see \link[antaresRead]{removeVirtualAreas}
+#' @param reassignCosts \code{boolean or list}, see \link[antaresRead]{removeVirtualAreas}
+#' @param newCols \code{boolean or list}, see \link[antaresRead]{removeVirtualAreas}
+#' @param overwrite \code{boolean or list}, overwrite old file
 #' @param supressMessages \code{boolean}, supress messages from \link[antaresRead]{readAntares} and \link[antaresRead]{removeVirtualAreas}
 #' 
 #' @examples
@@ -30,28 +30,49 @@
 #' \dontrun{
 #' # Write simulation one by one
 #' setSimulationPath("C:/Users/MyUser/Mystudy", 1)
-#' writeAntaresH5()
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY")
 #'
 #' # Write all simulations
 #' setSimulationPath("C:/Users/MyUser/Mystudy")
-#' writeAntaresH5(writeAllSimulations = TRUE)
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY", writeAllSimulations = TRUE)
 #'
 #' # Choose timestep to write
 #' setSimulationPath("C:/Users/MyUser/Mystudy", 1)
-#' writeAntaresH5(timeSteps = "hourly")
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY", timeSteps = "hourly")
 #'
 #' # Write with additionnal information
-#' writeAntaresH5(timeSteps = "hourly",
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY", timeSteps = "hourly",
 #'    misc = TRUE, thermalAvailabilities = TRUE,
 #'    hydroStorage = TRUE, hydroStorageMaxPower = TRUE, reserve = TRUE,
 #'    linkCapacity = TRUE, mustRun = TRUE, thermalModulation = TRUE)
 #' 
 #' # Write all data with a shorcut 
-#' writeAntaresH5(allData = TRUE)
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY", allData = TRUE)
+#' 
+#' #Remove virtuals areas
+#' 
+#' writeAntaresH5(path="PATH_TO_YOUR_STUDY", timeSteps = "hourly", overwrite = TRUE,
+#'                writeMcAll = FALSE, removeVirtualAreas = TRUE,
+#'                storageFlexibility =  "psp in-2",
+#'                production =  NULL, reassignCosts =FALSE, newCols = TRUE)
+#'                
+#' #Remove virtuals areas more than one call
+#' writeAntaresH5(
+#'                path="PATH_TO_YOUR_STUDY", 
+#'                timeSteps = "hourly", 
+#'                overwrite = TRUE,
+#'                writeMcAll = FALSE, 
+#'                removeVirtualAreas = TRUE, 
+#'                storageFlexibility = list("psp out", "psp in-2"),
+#'                production = list(NULL, NULL), 
+#'                reassignCosts = list(TRUE, FALSE), 
+#'                newCols = list(FALSE, TRUE)
+#'                )
+#'
 #'
 #' }
 #' @export
-writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "weekly", "monthly", "annual"),
+writeAntaresH5 <- function(path = NULL, timeSteps = c("hourly", "daily", "weekly", "monthly", "annual"),
                            opts = simOptions(),
                            writeMcAll = TRUE,
                            compress = 1,
@@ -140,25 +161,25 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
           library(antaresRead)
         })
         parallel::clusterExport(cl, c("path","opts","studyPath",
-                            "timeSteps",
-                            "writeMcAll",
-                            "compress",
-                            "misc",
-                            "thermalAvailabilities",
-                            "hydroStorage",
-                            "hydroStorageMaxPower",
-                            "reserve",
-                            "linkCapacity",
-                            "mustRun",
-                            "thermalModulation",
-                            "removeVirtualAreas",
-                            "storageFlexibility",
-                            "production",
-                            "reassignCosts",
-                            "newCols", 
-                            "overwrite",
-                            ".writeAntaresH5Fun",
-                            "supressMessages"
+                                      "timeSteps",
+                                      "writeMcAll",
+                                      "compress",
+                                      "misc",
+                                      "thermalAvailabilities",
+                                      "hydroStorage",
+                                      "hydroStorageMaxPower",
+                                      "reserve",
+                                      "linkCapacity",
+                                      "mustRun",
+                                      "thermalModulation",
+                                      "removeVirtualAreas",
+                                      "storageFlexibility",
+                                      "production",
+                                      "reassignCosts",
+                                      "newCols", 
+                                      "overwrite",
+                                      ".writeAntaresH5Fun",
+                                      "supressMessages"
         ), envir = environment())
         
         parallel::parSapplyLB(cl, studieSToWrite, function(X){
@@ -183,24 +204,24 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
           
           
           .writeAntaresH5Fun(path = pathStud,
-                                           timeSteps = timeSteps,
-                                           opts = opts,
-                                           writeMcAll = writeMcAll,
-                                           compress = compress,
-                                           misc = misc,
-                                           thermalAvailabilities = thermalAvailabilities,
-                                           hydroStorage = hydroStorage,
-                                           hydroStorageMaxPower = hydroStorageMaxPower,
-                                           reserve = reserve,
-                                           linkCapacity = linkCapacity,
-                                           mustRun = mustRun,
-                                           thermalModulation = thermalModulation,
-                                           removeVirtualAreas = removeVirtualAreas,
-                                           storageFlexibility = storageFlexibility,
-                                           production = production,
-                                           reassignCosts = reassignCosts,
-                                           newCols = newCols,
-                                           supressMessages = supressMessages)
+                             timeSteps = timeSteps,
+                             opts = opts,
+                             writeMcAll = writeMcAll,
+                             compress = compress,
+                             misc = misc,
+                             thermalAvailabilities = thermalAvailabilities,
+                             hydroStorage = hydroStorage,
+                             hydroStorageMaxPower = hydroStorageMaxPower,
+                             reserve = reserve,
+                             linkCapacity = linkCapacity,
+                             mustRun = mustRun,
+                             thermalModulation = thermalModulation,
+                             removeVirtualAreas = removeVirtualAreas,
+                             storageFlexibility = storageFlexibility,
+                             production = production,
+                             reassignCosts = reassignCosts,
+                             newCols = newCols,
+                             supressMessages = supressMessages)
           
           
         })
@@ -282,7 +303,7 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
                                reassignCosts,
                                newCols,
                                supressMessages){
-   
+  
   if(!requireNamespace("rhdf5", versionCheck = list(op = ">=", version = rhdf5_version))) stop(rhdf5_message)
   
   
@@ -326,20 +347,7 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
       
       #Read data
       if(messageS){
-      res <- readAntares(areas = "all" ,
-                         links = "all",
-                         clusters = "all",
-                         districts = "all",
-                         mcYears = mcY,
-                         timeStep = timeStep, opts = opts, showProgress = FALSE,
-                         misc = misc, thermalAvailabilities = thermalAvailabilities,
-                         hydroStorage = hydroStorage, hydroStorageMaxPower = hydroStorageMaxPower,
-                         reserve = reserve, linkCapacity = linkCapacity, mustRun = mustRun,
-                         thermalModulation = thermalModulation)
-      
-      
-      }else{
-        res <- suppressWarnings(suppressMessages(readAntares(areas = "all" ,
+        res <- readAntares(areas = "all" ,
                            links = "all",
                            clusters = "all",
                            districts = "all",
@@ -348,23 +356,51 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
                            misc = misc, thermalAvailabilities = thermalAvailabilities,
                            hydroStorage = hydroStorage, hydroStorageMaxPower = hydroStorageMaxPower,
                            reserve = reserve, linkCapacity = linkCapacity, mustRun = mustRun,
-                           thermalModulation = thermalModulation)))
+                           thermalModulation = thermalModulation)
+        
+        
+      }else{
+        res <- suppressWarnings(suppressMessages(readAntares(areas = "all" ,
+                                                             links = "all",
+                                                             clusters = "all",
+                                                             districts = "all",
+                                                             mcYears = mcY,
+                                                             timeStep = timeStep, opts = opts, showProgress = FALSE,
+                                                             misc = misc, thermalAvailabilities = thermalAvailabilities,
+                                                             hydroStorage = hydroStorage, hydroStorageMaxPower = hydroStorageMaxPower,
+                                                             reserve = reserve, linkCapacity = linkCapacity, mustRun = mustRun,
+                                                             thermalModulation = thermalModulation)))
         
       }
       
       if(removeVirtualAreas){
-        if(messageS){
-        res <- removeVirtualAreas(res,
-                           storageFlexibility = storageFlexibility,
-                           production = production,
-                           reassignCosts = reassignCosts,
-                           newCols = newCols)
+        if(!(is.list(storageFlexibility)))
+        {
+          if(messageS){
+            res <- removeVirtualAreas(res,
+                                      storageFlexibility = storageFlexibility,
+                                      production = production,
+                                      reassignCosts = reassignCosts,
+                                      newCols = newCols)
+          }else{
+            res <-  suppressWarnings(suppressMessages(removeVirtualAreas(res,
+                                                                         storageFlexibility = storageFlexibility,
+                                                                         production = production,
+                                                                         reassignCosts = reassignCosts,
+                                                                         newCols = newCols)))
+          }
         }else{
-          res <-  suppressWarnings(suppressMessages(removeVirtualAreas(res,
-                                    storageFlexibility = storageFlexibility,
-                                    production = production,
-                                    reassignCosts = reassignCosts,
-                                    newCols = newCols)))
+          
+          for(i in 1:length(storageFlexibility)){
+            res <-  suppressWarnings(
+              suppressMessages(
+                removeVirtualAreas(res,
+                                   storageFlexibility = storageFlexibility[[i]],
+                                   production = production[[i]],
+                                   reassignCosts = reassignCosts[[i]],
+                                   newCols = newCols[[i]])))
+          }
+          
         }
       }
       
@@ -393,7 +429,7 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
         if(messageS){
           layout <- readLayout()
         }else{
-        layout <- suppressWarnings(suppressMessages(readLayout()))
+          layout <- suppressWarnings(suppressMessages(readLayout()))
         }
         s <- serialize(layout, NULL, ascii = TRUE)
         rhdf5::h5write.default(rawToChar(s), path, paste0(timeStep, "/inputs/layout"))
@@ -401,14 +437,14 @@ writeAntaresH5 <- function(path = getwd(), timeSteps = c("hourly", "daily", "wee
         if(messageS){
           cldesc <- readClusterDesc()
         }else{
-        cldesc <- suppressWarnings(suppressMessages(readClusterDesc()))
+          cldesc <- suppressWarnings(suppressMessages(readClusterDesc()))
         }
         s <- serialize(cldesc, NULL, ascii = TRUE)
         rhdf5::h5write.default(rawToChar(s), path, paste0(timeStep, "/inputs/cldesc"))
         if(messageS){
           bc <- readBindingConstraints()
         }else{
-        bc <- suppressWarnings(suppressMessages(readBindingConstraints()))
+          bc <- suppressWarnings(suppressMessages(readBindingConstraints()))
         }
         s <- serialize(bc, NULL, ascii = TRUE)
         rhdf5::h5write.default(rawToChar(s), path, paste0(timeStep, "/inputs/buildingcte"))
