@@ -10,11 +10,5 @@ if(requireNamespace("rhdf5")){
                  "Invalid path argument. File not found. Must be a .h5 file or a repertory with .h5 file(s)", fixed=TRUE)
   })
   
-  test_that("h5 : Error no file", {
-    empyfile <- paste0(tpDir, "\\nothing")
-    dir.create(empyfile)
-    expect_error(setSimulationPathH5(empyfile),
-                 "Not available .h5 file in your directory", fixed=TRUE)
-  })
   
 }
